# Cortex Xpanse Asset Management
This script gets a list of Services determined by its underlying Asset(s).

This example uses:
* Assets API
* Services API

## Install
```
pip install -r requirements.txt
```

## Usage
Example:
```
python get_services_by_asset.py --asset-type "domain"
```
